@@ -4,10 +4,10 @@ use strict;
 use warnings;
 
 our $VERSION;
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use Net::DNS qw(:DEFAULT);
-use base qw(Exporter Net::DNS);
+use base     qw(Exporter Net::DNS);
 
 our @EXPORT = @Net::DNS::EXPORT;
 
@@ -36,80 +36,72 @@ configured nameservers.
 
 =cut
 
-require Net::DNS::Question;
 
-package Net::DNS::Question;
+{
 
-sub unicast_response {
-	my ( $self, @value ) = @_;				# uncoverable pod
-	for (@value) { $self->{qclass} |= ( $_ << 15 ) }
-	return $self->{qclass} >> 15;
-}
+	package Net::DNS::Resolver;	## Add methods to (otherwise empty) package
 
+	my $NAME_REGEX = q/\.(local|254\.169\.in-addr\.arpa|[89AB]\.E\.F\.ip6\.arpa)$/;
 
-require Net::DNS::RR;
+	sub send {
+		my ( $self, @argument ) = @_;
+		my $packet = $self->_make_query_packet(@argument);
+		my ($q) = $packet->question;
 
-package Net::DNS::RR;
+		if ( $q->qname =~ /$NAME_REGEX/oi ) {
+			local $packet->{status} = 0;
+			local @{$self}{qw(nameservers nameserver4 nameserver6 port retrans)};
+			$self->_reset_errorstring;
+			$self->nameservers( @{$self->{multicast_group}} );
+			$self->port( $self->{multicast_port} );
+			$self->retrans(3);
+			return $self->_send_udp( $packet, $packet->data );
+		}
 
-sub cache_flush {
-	my ( $self, @value ) = @_;				# uncoverable pod
-	for (@value) { $self->{qclass} |= ( $_ << 15 ) }
-	return $self->{qclass} >> 15;
-}
-
-
-require Net::DNS::Resolver;
-
-package Net::DNS::Resolver;
-
-my $defaults = __PACKAGE__->_defaults;
-$defaults->{multicast_group} = [qw(FF02::FB 224.0.0.251)];
-$defaults->{multicast_port}  = 5353;
-
-my $NAME_REGEX = q/\.(local|254\.169\.in-addr\.arpa|[89AB]\.E\.F\.ip6\.arpa)$/;
-
-sub send {
-	my ( $self, @argument ) = @_;
-	my $packet = $self->_make_query_packet(@argument);
-	my ($q) = $packet->question;
-
-	if ( $q->qname =~ /$NAME_REGEX/oi ) {
-		local $packet->{status} = 0;
-		local @{$self}{qw(nameservers nameserver4 nameserver6 port retrans)};
-		$self->_reset_errorstring;
-		$self->nameservers( @{$self->{multicast_group}} );
-		$self->port( $self->{multicast_port} );
-		$self->retrans(3);
-		return $self->_send_udp( $packet, $packet->data );
+		return $self->SUPER::send($packet);
 	}
 
-	return $self->SUPER::send($packet);
-}
+	sub bgsend {
+		my ( $self, @argument ) = @_;
+		my $packet = $self->_make_query_packet(@argument);
+		my ($q) = $packet->question;
 
-sub bgsend {
-	my ( $self, @argument ) = @_;
-	my $packet = $self->_make_query_packet(@argument);
-	my ($q) = $packet->question;
+		if ( $q->qname =~ /$NAME_REGEX/oi ) {
+			local $packet->{status} = 0;
+			local @{$self}{qw(nameservers nameserver4 nameserver6 port)};
+			$self->_reset_errorstring;
+			$self->nameservers( @{$self->{multicast_group}} );
+			$self->port( $self->{multicast_port} );
+			return $self->_bgsend_udp( $packet, $packet->data );
+		}
 
-	if ( $q->qname =~ /$NAME_REGEX/oi ) {
-		local $packet->{status} = 0;
-		local @{$self}{qw(nameservers nameserver4 nameserver6 port)};
-		$self->_reset_errorstring;
-		$self->nameservers( @{$self->{multicast_group}} );
-		$self->port( $self->{multicast_port} );
-		$q->unicast_response(1);
-		return $self->_bgsend_udp( $packet, $packet->data );
+		return $self->SUPER::bgsend($packet);
 	}
 
-	return $self->SUPER::bgsend($packet);
-}
-
-sub string {
-	my $self = shift;
-	return join( '', $self->SUPER::string, <<END );
+	sub string {
+		my $self = shift;
+		return join( '', $self->SUPER::string, <<END );
 ;; multicast_group	@{$self->{multicast_group}}
 ;; multicast_ port	$self->{multicast_port}
 END
+	}
+
+	my $defaults = __PACKAGE__->_defaults;
+	$defaults->{multicast_group} = [qw(FF02::FB 224.0.0.251)];
+	$defaults->{multicast_port}  = 5353;
+}
+
+
+sub Net::DNS::Question::unicast_response {
+	my ( $self, @value ) = @_;				# uncoverable pod
+	for (@value) { $self->{qclass} |= ( $_ << 15 ) }
+	return $self->{qclass} >> 15;
+}
+
+sub Net::DNS::RR::cache_flush {
+	my ( $self, @value ) = @_;				# uncoverable pod
+	for (@value) { $self->{class} |= ( $_ << 15 ) }
+	return $self->{class} >> 15;
 }
 
 
